@@ -1,11 +1,14 @@
 import json
+import os
 from pprint import pprint
 
 import click
+from pptx import Presentation
 
 from .parser import parser
 from .ppt import make_ppt
 from .schema import PPTTemplate
+from .stub import PPTTemplateStub
 
 
 @click.group()
@@ -36,7 +39,18 @@ def make_ppt_command(master_file, target_file, input):
     make_ppt(master_file, target_file, pages)
 
 
+@click.command("make_stub", short_help="Run a development server.")
+@click.argument('master_file', type=click.Path(exists=True, resolve_path=True))
+@click.option('--output', '-o', type=click.Path(exists=False, resolve_path=True))
+def make_stub_command(master_file, output=''):
+    master_ppt = Presentation(master_file)
+    template = PPTTemplateStub.load_by_pptx(master_ppt)
+    output_path = output or os.path.join(os.path.dirname(master_file), 'slide_stubs.py')
+    template.to_file(output_path)
+
+
 cli.add_command(make_schema)
 cli.add_command(make_ppt_command)
+cli.add_command(make_stub_command)
 if __name__ == '__main__':
     cli()
